==> eam-wshub-core-11.4-79-sources.jar: ch/cern/eam/wshub/core/services/workorders/entities/MeterReading.java <==
package ch.cern.eam.wshub.core.services.workorders.entities;

import ch.cern.eam.wshub.core.adapters.BigDecimalAdapter;
import ch.cern.eam.wshub.core.adapters.DateAdapter;

import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class MeterReading implements Serializable {
    private static final long serialVersionUID = -3004563411794265577L;

    private String UOM;
    private String equipmentCode;
    private BigDecimal actualValue;
    private BigDecimal differenceValue;
    private Date readingDate;
    private String woNumber;

    public String getUOM() {
        return UOM;
    }

    public void setUOM(String uOM) {
        UOM = uOM;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    @XmlJavaTypeAdapter(BigDecimalAdapter.class)
    public BigDecimal getActualValue() {
        return actualValue;
    }
    public void setActualValue(BigDecimal actualValue) {
        this.actualValue = actualValue;
    }

    @XmlJavaTypeAdapter(BigDecimalAdapter.class)
    public BigDecimal getDifferenceValue() {
        return differenceValue;
    }
    public void setDifferenceValue(BigDecimal differenceValue) {
        this.differenceValue = differenceValue;
    }

    @XmlJavaTypeAdapter(DateAdapter.class)
    public Date getReadingDate() {
        return readingDate;
    }

    public void setReadingDate(Date readingDate) {
        this.readingDate = readingDate;
    }

    @Override
    public String toString() {
        return "MeterReading [UOM=" + UOM + ", equipmentCode=" + equipmentCode + ", actualValue=" + actualValue
                + ", differenceValue=" + differenceValue + ", readingDate=" + readingDate + "]";
    }

    public String getWoNumber() {
        return woNumber;
    }

    public void setWoNumber(String woNumber) {
        this.woNumber = woNumber;
    }


}

==> eam-wshub-core-12.1-24-sources.jar: ch/cern/eam/wshub/core/services/workorders/entities/MeterReading.java <==
package ch.cern.eam.wshub.core.services.workorders.entities;

import ch.cern.eam.wshub.core.adapters.BigDecimalAdapter;
import ch.cern.eam.wshub.core.adapters.DateAdapter;
import ch.cern.eam.wshub.core.annotations.InforField;

import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class MeterReading implements Serializable {
    private static final long serialVersionUID = -3004563411794265577L;

    @InforField(xpath = "USAGEUOMID/UOMCODE")
    private String UOM;
    @InforField(xpath = "TARGETEQUIPMENTID/EQUIPMENTCODE")
    private String equipmentCode;
    @InforField(xpath = "TARGETEQUIPMENTID/ORGANIZATIONID/ORGANIZATIONCODE")
    private String equipmentOrganization;
    private BigDecimal actualValue;
    private BigDecimal differenceValue;
    private Date readingDate;
    @InforField(xpath = "WORKORDERID/JOBNUM")
    private String woNumber;

    public String getUOM() {
        return UOM;
    }

    public void setUOM(String uOM) {
        UOM = uOM;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public String getEquipmentOrganization() {
        return equipmentOrganization;
    }

    public void setEquipmentOrganization(String equipmentOrganization) {
        this.equipmentOrganization = equipmentOrganization;
    }

    @XmlJavaTypeAdapter(BigDecimalAdapter.class)
    public BigDecimal getActualValue() {
        return actualValue;
    }
    public void setActualValue(BigDecimal actualValue) {
        this.actualValue = actualValue;
    }

    @XmlJavaTypeAdapter(BigDecimalAdapter.class)
    public BigDecimal getDifferenceValue() {
        return differenceValue;
    }
    public void setDifferenceValue(BigDecimal differenceValue) {
        this.differenceValue = differenceValue;
    }

    @XmlJavaTypeAdapter(DateAdapter.class)
    public Date getReadingDate() {
        return readingDate;
    }

    public void setReadingDate(Date readingDate) {
        this.readingDate = readingDate;
    }

    @Override
    public String toString() {
        return "MeterReading [UOM=" + UOM + ", equipmentCode=" + equipmentCode + ", actualValue=" + actualValue
                + ", differenceValue=" + differenceValue + ", readingDate=" + readingDate + "]";
    }

    public String getWoNumber() {
        return woNumber;
    }

    public void setWoNumber(String woNumber) {
        this.woNumber = woNumber;
    }


}
